jactorch.vision.conv
====================

.. automodule:: jactorch.vision.conv

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      CustomKernel
      MaxPoolingKernelDef
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      custom_kernel
   
   

   
   
   








.. rubric:: Class CustomKernel
.. autoclass:: CustomKernel
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class MaxPoolingKernelDef
.. autoclass:: MaxPoolingKernelDef
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: custom_kernel


